@@ -7,7 +7,10 @@ use crate::enum_args::{
     column_encoding_from_str, compression_from_str, EncodingArgument, COMPRESSION_VARIANTS,
 };
 use anyhow::{bail, Error};
-use odbc_api::{escape_attribute_value, Connection, DriverCompleteOption, Environment};
+use odbc_api::{
+    escape_attribute_value, handles::OutputStringBuffer, Connection, DriverCompleteOption,
+    Environment,
+};
 use parquet::basic::{Compression, Encoding};
 use std::{fs::File, path::PathBuf};
 
@@ -154,6 +157,13 @@ pub struct QueryOpt {
     /// For each placeholder question mark (`?`) in the query text one parameter must be passed at
     /// the end of the command line.
     parameters: Vec<String>,
+    /// Tells the odbc2parquet, that the ODBC driver does not support binding 64 Bit integers (aka
+    /// S_C_BIGINT in ODBC speak). This will cause the odbc2parquet to query large integers as text
+    /// instead and convert them to 64 Bit integers itself. Setting this flag will not affect the
+    /// output, but may incurr a performance penality. In case you are using an Oracle Database it
+    /// can make queries work which did not before, because Oracle does not support 64 Bit integers.
+    #[clap(long)]
+    driver_does_not_support_64bit_integers: bool,
 }
 
 #[derive(Args)]
@@ -293,6 +303,10 @@ fn open_connection<'e>(
         DriverCompleteOption::NoPrompt
     };
 
-    let conn = odbc_env.driver_connect(&cs, None, driver_completion)?;
+    // We are not interessted in the completed connection string, beyond creating a connection, so
+    // we pass an empty buffer.
+    let mut completed_connection_string = OutputStringBuffer::empty();
+
+    let conn = odbc_env.driver_connect(&cs, &mut completed_connection_string, driver_completion)?;
     Ok(conn)
 }
